@@ -4,8 +4,13 @@ from typing import Generator, Optional, Sequence, Tuple, Union
 
 from libcst import (
     Arg,
+    Attribute,
     BaseExpression,
+    BaseSmallStatement,
     Call,
+    CSTNode,
+    ImportAlias,
+    ImportFrom,
     ImportStar,
     MaybeSentinel,
     Name,
@@ -13,9 +18,9 @@ from libcst import (
     RemoveFromParent,
 )
 from libcst import matchers as m
-from libcst._nodes.statement import BaseSmallStatement, ImportAlias, ImportFrom
 from libcst.codemod import ContextAwareTransformer
 from libcst.codemod.visitors import AddImportsVisitor
+from libcst.metadata import Scope, ScopeProvider
 
 
 class BaseDjCodemodTransformer(ContextAwareTransformer, ABC):
@@ -33,7 +38,7 @@ def module_matcher(import_parts: Sequence) -> Union[m.BaseMatcherNode, m.DoNotCa
     return m.Attribute(value=value, attr=m.Name(attr))
 
 
-def import_from_matches(node: ImportFrom, module_parts: Sequence):
+def import_from_matches(node: ImportFrom, module_parts: Sequence) -> bool:
     """Check if an `ImportFrom` node matches sequence of module parts."""
     return m.matches(node, m.ImportFrom(module=module_matcher(module_parts)))
 
@@ -70,14 +75,6 @@ class BaseRenameTransformer(BaseDjCodemodTransformer, ABC):
     def entity_imported_as(self):
         return self.context.scratch.get(self.ctx_key_imported_as, None)
 
-    @property
-    def ctx_key_is_name_called(self):
-        return f"{self.rename_from}-is_name_called"
-
-    @property
-    def entity_is_name_called(self):
-        return self.context.scratch.get(self.ctx_key_is_name_called, False)
-
     @property
     def is_imported_with_old_name(self):
         is_imported = self.ctx_key_imported_as in self.context.scratch
@@ -91,6 +88,7 @@ class BaseRenameTransformer(BaseDjCodemodTransformer, ABC):
             return super().leave_ImportFrom(original_node, updated_node)
         # This is a match
         new_names = list(self.gen_new_imported_names(updated_node.names))
+        self.save_import_scope(original_node)
         if not new_names:
             # Nothing left in the import statement: remove it
             return RemoveFromParent()
@@ -111,7 +109,26 @@ class BaseRenameTransformer(BaseDjCodemodTransformer, ABC):
                     continue
             yield import_alias
 
-    def tidy_new_imported_names(self, new_names):
+    def resolve_scope(self, node: CSTNode) -> Scope:
+        scopes_map = self.context.wrapper.resolve(ScopeProvider)
+        return scopes_map[node]
+
+    def save_import_scope(self, import_from: ImportFrom) -> None:
+        scope = self.resolve_scope(import_from)
+        self.context.scratch[self.ctx_key_import_scope] = scope
+
+    @property
+    def import_scope(self) -> Optional[Scope]:
+        return self.context.scratch.get(self.ctx_key_import_scope, None)
+
+    @property
+    def ctx_key_import_scope(self) -> str:
+        return f"{self.rename_from}-import_scope"
+
+    @staticmethod
+    def tidy_new_imported_names(
+        new_names: Sequence[ImportAlias],
+    ) -> Sequence[ImportAlias]:
         """Tidy up the updated list of imports"""
         # Sort them
         cleaned_names = sorted(new_names, key=lambda n: n.evaluated_name)
@@ -121,7 +138,7 @@ class BaseRenameTransformer(BaseDjCodemodTransformer, ABC):
             cleaned_names[-1] = last_name.with_changes(comma=MaybeSentinel.DEFAULT)
         return cleaned_names
 
-    def add_new_import(self, evaluated_name: Optional[str] = None):
+    def add_new_import(self, evaluated_name: Optional[str] = None) -> None:
         as_name = (
             self.entity_imported_as.name.value if self.entity_imported_as else None
         )
@@ -132,21 +149,53 @@ class BaseRenameTransformer(BaseDjCodemodTransformer, ABC):
             asname=as_name,
         )
 
+    @property
+    def ctx_key_is_name_called(self):
+        return f"{self.rename_from}-is_name_called"
+
+    @property
+    def entity_is_name_called(self):
+        return self.context.scratch.get(self.ctx_key_is_name_called, False)
+
     def visit_Call(self, node: Call) -> Optional[bool]:
         if self.is_imported_with_old_name and m.matches(
             node, m.Call(func=m.Name(self.old_name))
         ):
             self.context.scratch[self.ctx_key_is_name_called] = True
+        return None
 
     def leave_Call(self, original_node: Call, updated_node: Call) -> BaseExpression:
         self.context.scratch.pop(self.ctx_key_is_name_called, None)
         return super().leave_Call(original_node, updated_node)
 
+    @property
+    def ctx_key_is_name_in_attribute(self):
+        return f"{self.rename_from}-is_in_attribute"
+
+    @property
+    def entity_is_in_attribute(self):
+        return self.context.scratch.get(self.ctx_key_is_name_in_attribute, False)
+
+    def visit_Attribute(self, node: Attribute) -> Optional[bool]:
+        if self.is_imported_with_old_name and m.matches(
+            node, m.Attribute(attr=m.Name(self.old_name))
+        ):
+            self.context.scratch[self.ctx_key_is_name_in_attribute] = True
+        return super().visit_Attribute(node)
+
+    def leave_Attribute(
+        self, original_node: Attribute, updated_node: Attribute
+    ) -> BaseExpression:
+        self.context.scratch.pop(self.ctx_key_is_name_in_attribute, None)
+        return super().leave_Attribute(original_node, updated_node)
+
     def leave_Name(self, original_node: Name, updated_node: Name) -> BaseExpression:
         if (
             self.is_imported_with_old_name
             and not self.entity_is_name_called
+            and not self.entity_is_in_attribute
             and m.matches(updated_node, m.Name(value=self.old_name))
+            and self.resolve_scope(original_node) == self.import_scope
         ):
             return updated_node.with_changes(value=self.new_name)
         return super().leave_Name(original_node, updated_node)
